# This file was auto-generated by ZETUP
#
# Zimmermann's Extensible Tools for Unified Project setups
#
# https://github.com/zimmermanncode/zetup

from __future__ import print_function

from setuptools import setup


dist = None
try:
    dist = setup(
        setup_requires=["zetup >= 0.2.60"],

        use_zetup=True,
    )
finally:
    if dist is not None and hasattr(dist, 'zetup_made'):
        dist.zetup_made.clean()